write_ignore: Create a .gitignore File

View source: R/write_ignore.R

write_ignoreR Documentation

Create a .gitignore File

Description

Creates or opens a .gitignore file in a Quarto project. If the file already exists, it is opened directly. Otherwise, the opinionated template is downloaded from the frogger-templates repository.

Usage

write_ignore(path = here::here())

Arguments

path

Character. Path to the project directory. Default is current project root via here.

Value

Invisibly returns the path to the file.

See Also

init, write_quarto

Examples

## Not run: 
write_ignore()

## End(Not run)


froggeR documentation built on March 17, 2026, 9:06 a.m.