| save_brand | R Documentation |
This function saves the current _brand.yml file from an existing froggeR
Quarto project to your global (system-wide) froggeR configuration. This allows
you to reuse brand settings across multiple projects.
save_brand(save_logos = TRUE)
save_logos |
Logical. Should logo files from the |
This function:
Reads the project-level _brand.yml file
Saves it to your system-wide froggeR config directory
Optionally copies the logos directory for reuse in future projects
Prompts for confirmation if a global configuration already exists
The saved configuration is stored in rappdirs::user_config_dir('froggeR')
and will automatically be used in new froggeR projects created with
init or write_brand.
Invisibly returns NULL after saving configuration file.
write_brand, save_variables
# Save brand settings from current project to global config
if (interactive()) save_brand()
# Save brand settings but skip logos
if (interactive()) save_brand(save_logos = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.