| write_quarto | R Documentation |
Downloads the Quarto template from the
frogger-templates
repository and writes it to the analysis/ directory. Errors if a file
with the same name already exists.
write_quarto(filename = "Untitled-1", path = here::here())
filename |
Character. The name of the file without the |
path |
Character. Path to the project directory. Default is current project
root via |
The file is written to analysis/<filename>.qmd. The analysis/
directory is created automatically if it does not exist.
Invisibly returns the path to the created Quarto document.
init, write_variables,
write_brand
## Not run:
# Create a Quarto document with the default name
write_quarto()
# Create a Quarto document with a custom name
write_quarto(filename = "analysis")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.